[−][src]Module librespot_protocol::pubsub
Generated file from pubsub.proto
Structs
| Subscription | Generated files are compatible only with the same version of protobuf runtime. |
Functions
| file_descriptor_proto |
Generated file from pubsub.proto
| Subscription | Generated files are compatible only with the same version of protobuf runtime. |
| file_descriptor_proto |